@@ -10,20 +10,19 @@
 
 print.summary.pandemicEstimated=function(x,...){
 
-  if(x$n_waves==1 && is.null(x$seasonal_effect)){   # gen logistic
-    name="static generalized logistic"
-  } else if(is.null(x$seasonal_effect)==FALSE){         #gen logistic with seasonal effect
-    name="static seasonal generalized logistic"
+
+  if(x$n_waves==1){
+    name="static generalized logistic"   # name="static generalized logistic"
   } else {
     name=paste0("multi_waves(",x$n_waves,")")      #multiwaves
   }
 
   cat("pandemic_model")
-  cat("\n Distribution:       ", "poisson")
+  cat("\n Family:             ", x$family)
   cat("\n Mean function form: ", name)
   cat("\n Type of Case:       ", x$cases.type)
   cat("\n Location:           ", x$location)
-  if(is.null(x$seasonal_effect)==FALSE){
+  if(!is.null(x$seasonal_effect)){
   cat("\n Seasonal effect:    ", paste0(x$seasonal_effect,"(","d_",1:length(x$seasonal_effect),")" ) )
   }
   cat("\n 0bservations:       ", x$n,"\n")
@@ -53,45 +52,82 @@ print.summary.pandemicEstimated=function(x,...){
   print(x$init1)   #show only chain_id=1
 
 
-  if(x$n_waves==1 && is.null(x$seasonal_effect)){   #gen logistic
-    cat("\n------\n")
-    cat("Priors:\n")
-    cat("\n a ","~ ","Gamma(0.1, 0.1)")
-    cat("\n b ","~ ","LogNormal(0, 20)")
-    cat("\n c ","~ ","Gamma(2, 9)")
-    cat("\n f ","~ ","Gamma(0.01, 0.01)\n")
+  if(is.null(x$seasonal_effect)){
+
+    if(x$n_waves==1) {   #gen logistic
+      cat("\n------\n")
+      cat("Priors:\n")
+      if(x$family=="negbin"){
+        cat("\n phi","~ ","Gamma(0.1, 0.1)")
+      }
+      cat("\n a  ","~ ","Gamma(0.1, 0.1)")
+      cat("\n b  ","~ ","LogNormal(0, 20)")
+      cat("\n c  ","~ ","Gamma(2, 9)")
+      cat("\n f  ","~ ","Gamma(0.01, 0.01)\n")
+    } else {
+
+      cat("\n------\n")
+      cat("Priors:\n")
+      if(x$family=="negbin"){
+        cat("\n phi     ","~ ","Gamma(0.1, 0.1)")
+      }
+      cat("\n a_i     ","~ ","Gamma(0.1, 0.1)")
+      cat("\n alpha_i ","~ ","Gamma(0.01, 0.01)")
+      cat("\n b_i     ","~ ","LogNormal(0, 20)")
+      cat("\n c_i     ","~ ","Gamma(2, 9)")
+      cat("\n delta_i ","~ ","Normal(0, 100)\n")
+    }
+
+
+  } else {
+
+    if(x$n_waves==1){
+      cat("\n------\n")
+      cat("Priors:\n")
+      if(x$family=="negbin"){
+        cat("\n phi ","~ ","Gamma(0.1, 0.1)")
+      }
+      cat("\n a   ","~ ","Gamma(0.1, 0.1)")
+      cat("\n b   ","~ ","LogNormal(0, 20)")
+      cat("\n c   ","~ ","Gamma(2, 9)")
+      cat("\n d_i ","~ ","Gamma(2,1)")
+      cat("\n f   ","~ ","Gamma(0.01, 0.01)\n")
+    } else {
+
+      cat("\n------\n")
+      cat("Priors:\n")
+      if(x$family=="negbin"){
+        cat("\n phi     ","~ ","Gamma(0.1, 0.1)")
+      }
+      cat("\n a_i     ","~ ","Gamma(0.1, 0.1)")
+      cat("\n alpha_i ","~ ","Gamma(0.01, 0.01)")
+      cat("\n b_i     ","~ ","LogNormal(0, 20)")
+      cat("\n c_i     ","~ ","Gamma(2, 9)")
+      cat("\n d_i     ","~ ","Gamma(2,1)")
+      cat("\n delta_i ","~ ","Normal(0, 100)\n")
+
+    }
+
   }
 
-  if(is.null(x$seasonal_effect)==FALSE){             #gen logistic with seasonal effect
-    cat("\n------\n")
-    cat("Priors:\n")
-    cat("\n a   ","~ ","Gamma(0.1, 0.1)")
-    cat("\n b   ","~ ","LogNormal(0, 20)")
-    cat("\n c   ","~ ","Gamma(2, 9)")
-    cat("\n d_i ","~ ","Gamma(2,1)")
-    cat("\n f   ","~ ","Gamma(0.01, 0.01)\n")
-  }
 
-  if(x$n_waves==2){
-    cat("\n------\n")
-    cat("Priors:\n")
-    cat("\n a_i     ","~ ","Gamma(0.1, 0.1)")
-    cat("\n alpha_i ","~ ","Gamma(0.01, 0.01)")
-    cat("\n b_i     ","~ ","LogNormal(0, 20)")
-    cat("\n c_i     ","~ ","Gamma(2, 9)")
-    cat("\n delta_i ","~ ","Normal(0, 100)\n")
-  }
-
-  if(x$n_waves==1){              #gen logistic ou gen logistic with seasonal effect
+  if(x$n_waves==1){              #gen logistic ou gen logistic
     cat("\nRestrictions:")
     cat("\n 1: ", "a/b^f","<",x$p,"*population")
-    cat("\n 2: ", "f > 1\n")
-  }
+    if(x$family=="negbin"){
+      cat("\n 2: ", "f >",x$fTrunc)
+      cat("\n 3: ", "phi >",x$phiTrunc)
+    } else {
+      cat("\n 2: ", "f > 1\n")
+    }
 
-  if(x$n_waves==2){              #multiwaves:  2waves
+  } else {            #multiwaves
     cat("\nRestrictions:")
-    cat("\n 1: ", "a_1/b_1","<",x$p,"*population")
-    cat("\n 2: ", "a_2/b_2","<",x$p,"*population\n")
+    cat("\n 1: ", "a_i/b_i","<",x$p,"*population")
+    cat("\n 2: ", "alpha_i > 0")
+    if(x$family=="negbin"){
+    cat("\n 3: ","phi",">",x$phiTrunc)
+    }
   }
 
 
